@@ -1,3 +1,5 @@
+"""Utilities for making it easier to write tests."""
+
 import datetime as dt
 import json
 import logging
@@ -135,13 +137,17 @@ def multi_assert_not_in(items: Iterable, container: Iterable) -> bool:
 
 
 def add_new_token(
-    user: User, character: EveCharacter, scopes: List[str] = None
+    user: User,
+    character: EveCharacter,
+    scopes: List[str] = None,
+    owner_hash: str = None,
 ) -> Token:
     """Generate a new token for a user based on a character."""
     return _store_as_Token(
         _generate_token(
             character_id=character.character_id,
             character_name=character.character_name,
+            owner_hash=owner_hash,
             scopes=scopes,
         ),
         user,
@@ -151,6 +157,7 @@ def add_new_token(
 def _generate_token(
     character_id: int,
     character_name: str,
+    owner_hash: str = None,
     access_token: str = "access_token",
     refresh_token: str = "refresh_token",
     scopes: list = None,
@@ -166,6 +173,8 @@ def _generate_token(
             "esi-wallet.read_character_wallet.v1",
             "esi-universe.read_structures.v1",
         ]
+    if owner_hash is None:
+        owner_hash = random_string(28)
     token = {
         "access_token": access_token,
         "token_type": "Bearer",
@@ -177,7 +186,7 @@ def _generate_token(
         "ExpiresOn": dt_eveformat(timestamp_dt + dt.timedelta(seconds=expires_in)),
         "Scopes": " ".join(list(scopes)),
         "TokenType": "Character",
-        "CharacterOwnerHash": random_string(28),
+        "CharacterOwnerHash": owner_hash,
         "IntellectualProperty": "EVE",
     }
     return token
@@ -394,7 +403,7 @@ def create_eve_character(
 
 
 def next_number(key=None) -> int:
-    """Generate consequetive numbers. Optionally numbers are generates for given key."""
+    """Generate consecutive numbers. Optionally numbers are generates for given key."""
     if key is None:
         key = "_general"
     try:
